@@ -1,7 +1,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2013-2020 Alban 'spl0k' Féron
+# Copyright (C) 2013-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -9,11 +9,11 @@ import re
 import string
 
 from flask import current_app, request
-from pony.orm import ObjectNotFound, select, count
+from peewee import fn
 
 from ..db import Folder, Artist, Album, Track
 
-from . import get_entity, get_entity_id, api_routing
+from . import get_entity, get_root_folder, api_routing
 
 
 @api_routing("/getMusicFolders")
@@ -23,7 +23,7 @@ def list_folders():
         {
             "musicFolder": [
                 {"id": str(f.id), "name": f.name}
-                for f in Folder.select(lambda f: f.root).order_by(Folder.name)
+                for f in Folder.select().where(Folder.root).order_by(Folder.name)
             ]
         },
     )
@@ -49,6 +49,27 @@ def ignored_articles_str():
     return " ".join(articles.split())
 
 
+def build_indexes(source):
+    indexes = {}
+    pattern = build_ignored_articles_pattern()
+    for item in source:
+        name = item.name
+        if pattern:
+            name = re.sub(pattern, "", name, flags=re.I)
+        index = name[0].upper()
+        if index in string.digits:
+            index = "#"
+        elif index not in string.ascii_letters:
+            index = "?"
+
+        if index not in indexes:
+            indexes[index] = []
+
+        indexes[index].append((item, name))
+
+    return indexes
+
+
 @api_routing("/getIndexes")
 def list_indexes():
     musicFolderId = request.values.get("musicFolderId")
@@ -57,14 +78,9 @@ def list_indexes():
         ifModifiedSince = int(ifModifiedSince) / 1000
 
     if musicFolderId is None:
-        folders = Folder.select(lambda f: f.root)[:]
+        folders = Folder.select().where(Folder.root)[:]
     else:
-        mfid = get_entity_id(Folder, musicFolderId)
-        folder = Folder[mfid]
-        if not folder.root:
-            raise ObjectNotFound(Folder, mfid)
-
-        folders = [folder]
+        folders = [get_root_folder(musicFolderId)]
 
     last_modif = max(f.last_scan for f in folders)
     if ifModifiedSince is not None and last_modif < ifModifiedSince:
@@ -80,26 +96,10 @@ def list_indexes():
     artists = []
     children = []
     for f in folders:
-        artists += f.children.select()[:]
-        children += f.tracks.select()[:]
-
-    indexes = {}
-    pattern = build_ignored_articles_pattern()
-    for artist in artists:
-        name = artist.name
-        if pattern:
-            name = re.sub(pattern, "", name, flags=re.I)
-        index = name[0].upper()
-        if index in string.digits:
-            index = "#"
-        elif index not in string.ascii_letters:
-            index = "?"
-
-        if index not in indexes:
-            indexes[index] = []
-
-        indexes[index].append((artist, name))
+        artists += f.children[:]
+        children += f.tracks[:]
 
+    indexes = build_indexes(artists)
     return request.formatter(
         "indexes",
         {
@@ -138,9 +138,12 @@ def list_genres():
         {
             "genre": [
                 {"value": genre, "songCount": sc, "albumCount": ac}
-                for genre, sc, ac in select(
-                    (t.genre, count(), count(t.album)) for t in Track if t.genre
+                for genre, sc, ac in Track.select(
+                    Track.genre, fn.count("*"), fn.count(Track.album.distinct())
                 )
+                .where(Track.genre.is_null(False))
+                .group_by(Track.genre)
+                .tuples()
             ]
         },
     )
@@ -148,24 +151,14 @@ def list_genres():
 
 @api_routing("/getArtists")
 def list_artists():
-    # According to the API page, there are no parameters?
-    indexes = {}
-    pattern = build_ignored_articles_pattern()
-    for artist in Artist.select():
-        name = artist.name or "?"
-        if pattern:
-            name = re.sub(pattern, "", name, flags=re.I)
-        index = name[0].upper()
-        if index in string.digits:
-            index = "#"
-        elif index not in string.ascii_letters:
-            index = "?"
+    mfid = request.values.get("musicFolderId")
 
-        if index not in indexes:
-            indexes[index] = []
-
-        indexes[index].append((artist, name))
+    query = Artist.select()
+    if mfid is not None:
+        folder = get_root_folder(mfid)
+        query = Artist.select().join(Track).where(Track.root_folder == folder)
 
+    indexes = build_indexes(query)
     return request.formatter(
         "artists",
         {
