@@ -1,12 +1,11 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2018-2019 Alban 'spl0k' Féron
+# Copyright (C) 2018-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
-from pony.orm import rollback
-from pony.orm import ObjectNotFound
+from peewee import DoesNotExist
 from werkzeug.exceptions import BadRequestKeyError
 
 from . import api
@@ -15,25 +14,21 @@ from .exceptions import GenericError, MissingParameter, NotFound, ServerError
 
 @api.errorhandler(ValueError)
 def value_error(e):
-    rollback()
     return GenericError("{0.__class__.__name__}: {0}".format(e))
 
 
 @api.errorhandler(BadRequestKeyError)
 def key_error(e):
-    rollback()
     return MissingParameter()
 
 
-@api.errorhandler(ObjectNotFound)
+@api.errorhandler(DoesNotExist)
 def object_not_found(e):
-    rollback()
-    return NotFound(e.entity.__name__)
+    return NotFound(e.__class__.__name__[: -len("DoesNotExist")])
 
 
 @api.errorhandler(500)
 def generic_error(e):  # pragma: nocover
-    rollback()
     return ServerError("{0.__class__.__name__}: {0}".format(e))
 
 
