@@ -1,18 +1,17 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2013-2020 Alban 'spl0k' Féron
+# Copyright (C) 2013-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
 from collections import OrderedDict
 from datetime import datetime
 from flask import request
-from pony.orm import select
 
 from ..db import Folder, Track, Artist, Album
 
-from . import api_routing
+from . import api_routing, get_root_folder
 from .exceptions import MissingParameter
 
 
@@ -29,22 +28,32 @@ def old_search():
     min_date = datetime.fromtimestamp(newer_than)
 
     if artist:
-        query = select(
-            t.folder.parent
-            for t in Track
-            if artist in t.folder.parent.name and t.folder.parent.created > min_date
+        Child = Folder.alias()
+        query = (
+            Folder.select()
+            .join(Child, on=Child.parent == Folder.id)
+            .join(Track, on=Track.folder == Child.id)
+            .where(Folder.name.contains(artist), Folder.created > min_date)
+            .distinct()
         )
     elif album:
-        query = select(
-            t.folder
-            for t in Track
-            if album in t.folder.name and t.folder.created > min_date
+        query = (
+            Folder.select()
+            .join(Track, on=Track.folder)
+            .where(Folder.name.contains(album), Folder.created > min_date)
+            .distinct()
         )
     elif title:
-        query = Track.select(lambda t: title in t.title and t.created > min_date)
+        query = Track.select().where(
+            Track.title.contains(title), Track.created > min_date
+        )
     elif anyf:
-        folders = Folder.select(lambda f: anyf in f.name and f.created > min_date)
-        tracks = Track.select(lambda t: anyf in t.title and t.created > min_date)
+        folders = Folder.select().where(
+            Folder.name.contains(anyf), Folder.created > min_date
+        )
+        tracks = Track.select().where(
+            Track.title.contains(anyf), Track.created > min_date
+        )
         res = folders[offset : offset + count]
         fcount = folders.count()
         if offset + count > fcount:
@@ -58,9 +67,11 @@ def old_search():
                 "totalHits": folders.count() + tracks.count(),
                 "offset": offset,
                 "match": [
-                    r.as_subsonic_child(request.user)
-                    if isinstance(r, Folder)
-                    else r.as_subsonic_child(request.user, request.client)
+                    (
+                        r.as_subsonic_child(request.user)
+                        if isinstance(r, Folder)
+                        else r.as_subsonic_child(request.user, request.client)
+                    )
                     for r in res
                 ],
             },
@@ -74,9 +85,11 @@ def old_search():
             "totalHits": query.count(),
             "offset": offset,
             "match": [
-                r.as_subsonic_child(request.user)
-                if isinstance(r, Folder)
-                else r.as_subsonic_child(request.user, request.client)
+                (
+                    r.as_subsonic_child(request.user)
+                    if isinstance(r, Folder)
+                    else r.as_subsonic_child(request.user, request.client)
+                )
                 for r in query[offset : offset + count]
             ],
         },
@@ -93,6 +106,7 @@ def new_search():
         album_offset,
         song_count,
         song_offset,
+        mfid,
     ) = map(
         request.values.get,
         (
@@ -102,6 +116,7 @@ def new_search():
             "albumOffset",
             "songCount",
             "songOffset",
+            "musicFolderId",
         ),
     )
 
@@ -111,14 +126,32 @@ def new_search():
     album_offset = int(album_offset) if album_offset else 0
     song_count = int(song_count) if song_count else 20
     song_offset = int(song_offset) if song_offset else 0
+    root = get_root_folder(mfid)
 
-    artists = select(
-        t.folder.parent for t in Track if query in t.folder.parent.name
-    ).limit(artist_count, artist_offset)
-    albums = select(t.folder for t in Track if query in t.folder.name).limit(
-        album_count, album_offset
+    Child = Folder.alias()
+    artists = (
+        Folder.select()
+        .join(Child, on=Child.parent == Folder.id)
+        .join(Track, on=Track.folder == Child.id)
+        .where(Folder.name.contains(query))
+        .distinct()
     )
-    songs = Track.select(lambda t: query in t.title).limit(song_count, song_offset)
+    albums = (
+        Folder.select()
+        .join(Track, on=Track.folder)
+        .where(Folder.name.contains(query))
+        .distinct()
+    )
+    songs = Track.select().where(Track.title.contains(query))
+
+    if root is not None:
+        artists = artists.where(Track.root_folder == root)
+        albums = albums.where(Track.root_folder == root)
+        songs = songs.where(Track.root_folder == root)
+
+    artists = artists.limit(artist_count).offset(artist_offset)
+    albums = albums.limit(album_count).offset(album_offset)
+    songs = songs.limit(song_count).offset(song_offset)
 
     return request.formatter(
         "searchResult2",
@@ -145,6 +178,7 @@ def search_id3():
         album_offset,
         song_count,
         song_offset,
+        mfid,
     ) = map(
         request.values.get,
         (
@@ -154,6 +188,7 @@ def search_id3():
             "albumOffset",
             "songCount",
             "songOffset",
+            "musicFolderId",
         ),
     )
 
@@ -163,12 +198,20 @@ def search_id3():
     album_offset = int(album_offset) if album_offset else 0
     song_count = int(song_count) if song_count else 20
     song_offset = int(song_offset) if song_offset else 0
+    root = get_root_folder(mfid)
 
-    artists = Artist.select(lambda a: query in a.name).limit(
-        artist_count, artist_offset
-    )
-    albums = Album.select(lambda a: query in a.name).limit(album_count, album_offset)
-    songs = Track.select(lambda t: query in t.title).limit(song_count, song_offset)
+    artists = Artist.select().where(Artist.name.contains(query))
+    albums = Album.select().where(Album.name.contains(query))
+    songs = Track.select().where(Track.title.contains(query))
+
+    if root is not None:
+        artists = artists.join(Track).where(Track.root_folder == root)
+        albums = albums.join(Track).where(Track.root_folder == root)
+        songs = songs.where(Track.root_folder == root)
+
+    artists = artists.limit(artist_count).offset(artist_offset)
+    albums = albums.limit(album_count).offset(album_offset)
+    songs = songs.limit(song_count).offset(song_offset)
 
     return request.formatter(
         "searchResult3",
