@@ -1,7 +1,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2013-2020 Alban 'spl0k' Féron
+# Copyright (C) 2013-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -11,8 +11,8 @@ from functools import wraps
 from ..db import User
 from ..managers.user import UserManager
 
-from . import api, decode_password
-from .exceptions import Forbidden, NotFound
+from . import decode_password, api_routing
+from .exceptions import Forbidden
 
 
 def admin_only(f):
@@ -25,7 +25,7 @@ def admin_only(f):
     return decorated
 
 
-@api.route("/getUser.view", methods=["GET", "POST"])
+@api_routing("/getUser")
 def user_info():
     username = request.values["username"]
 
@@ -33,17 +33,14 @@ def user_info():
         raise Forbidden()
 
     user = User.get(name=username)
-    if user is None:
-        raise NotFound("User")
-
     return request.formatter("user", user.as_subsonic_user())
 
 
-@api.route("/getUsers.view", methods=["GET", "POST"])
+@api_routing("/getUsers")
 @admin_only
 def users_info():
     return request.formatter(
-        "users", dict(user=[u.as_subsonic_user() for u in User.select()])
+        "users", {"user": [u.as_subsonic_user() for u in User.select()]}
     )
 
 
@@ -57,7 +54,7 @@ def get_roles_dict():
     return roles
 
 
-@api.route("/createUser.view", methods=["GET", "POST"])
+@api_routing("/createUser")
 @admin_only
 def user_add():
     username = request.values["username"]
@@ -71,7 +68,7 @@ def user_add():
     return request.formatter.empty
 
 
-@api.route("/deleteUser.view", methods=["GET", "POST"])
+@api_routing("/deleteUser")
 @admin_only
 def user_del():
     username = request.values["username"]
@@ -80,7 +77,7 @@ def user_del():
     return request.formatter.empty
 
 
-@api.route("/changePassword.view", methods=["GET", "POST"])
+@api_routing("/changePassword")
 def user_changepass():
     username = request.values["username"]
     password = request.values["password"]
@@ -94,20 +91,18 @@ def user_changepass():
     return request.formatter.empty
 
 
-@api.route("/updateUser.view", methods=["GET", "POST"])
+@api_routing("/updateUser")
 @admin_only
 def user_edit():
     username = request.values["username"]
     user = User.get(name=username)
-    if user is None:
-        raise NotFound("User")
 
     if "password" in request.values:
         password = decode_password(request.values["password"])
         UserManager.change_password2(user, password)
 
     email, admin, jukebox = map(
-        request.values.get, ["email", "adminRole", "jukeboxRole"]
+        request.values.get, ("email", "adminRole", "jukeboxRole")
     )
     if email is not None:
         user.mail = email
@@ -120,4 +115,6 @@ def user_edit():
         jukebox = jukebox in (True, "True", "true", 1, "1")
         user.jukebox = jukebox
 
+    user.save()
+
     return request.formatter.empty
