@@ -46,10 +46,10 @@ def add_folder_post():
     error = False
     name, path = map(request.form.get, ("name", "path"))
     if name in (None, ""):
-        flash("The name is required.")
+        flash("The name is required.", "danger")
         error = True
     if path in (None, ""):
-        flash("The path is required.")
+        flash("The path is required.", "danger")
         error = True
     if error:
         return render_template("addfolder.html")
@@ -57,10 +57,10 @@ def add_folder_post():
     try:
         FolderManager.add(name, path)
     except ValueError as e:
-        flash(str(e), "error")
+        flash(str(e), "danger")
         return render_template("addfolder.html")
 
-    flash(f"Folder '{name}' created. You should now run a scan")
+    flash(f"Folder '{name}' created. You should now run a scan", "success")
     return redirect(url_for("frontend.folder_index"))
 
 
@@ -69,11 +69,11 @@ def add_folder_post():
 def del_folder(id):
     try:
         FolderManager.delete(id)
-        flash("Deleted folder")
+        flash("Deleted folder", "success")
     except ValueError as e:
-        flash(str(e), "error")
+        flash(str(e), "danger")
     except Folder.DoesNotExist:
-        flash("No such folder", "error")
+        flash("No such folder", "danger")
 
     return redirect(url_for("frontend.folder_index"))
 
@@ -90,10 +90,10 @@ def scan_folder(id=None):
         DaemonClient(current_app.config["DAEMON"]["socket"]).scan(folders)
         flash("Scanning started")
     except ValueError as e:
-        flash(str(e), "error")
+        flash(str(e), "danger")
     except Folder.DoesNotExist:
-        flash("No such folder", "error")
+        flash("No such folder", "danger")
     except DaemonUnavailableError:
-        flash("Can't start scan", "error")
+        flash("Can't start scan", "danger")
 
     return redirect(url_for("frontend.folder_index"))
