@@ -1,7 +1,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2021 Alban 'spl0k' Féron
+# Copyright (C) 2021-2023 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -11,15 +11,11 @@ from ._base import BaseServer
 
 
 class GunicornApp(BaseApplication):
-    def __init__(self, app, **config):
-        self.__app = app
+    def __init__(self, **config):
         self.__config = config
 
         super().__init__()
 
-    def load(self):
-        return self.__app
-
     def load_config(self):
         socket = self.__config["socket"]
         host = self.__config["host"]
@@ -28,9 +24,9 @@ class GunicornApp(BaseApplication):
         threads = self.__config["threads"]
 
         if socket is not None:
-            self.cfg.set("bind", "unix:{}".format(socket))
+            self.cfg.set("bind", f"unix:{socket}")
         else:
-            self.cfg.set("bind", "{}:{}".format(host, port))
+            self.cfg.set("bind", f"{host}:{port}")
 
         if processes is not None:
             self.cfg.set("workers", processes)
@@ -39,9 +35,10 @@ class GunicornApp(BaseApplication):
 
 
 class GunicornServer(BaseServer):
-    def __init__(self, app, **kwargs):
-        super().__init__(app, **kwargs)
-        self.__server = GunicornApp(app, **kwargs)
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.__server = GunicornApp(**kwargs)
+        self.__server.load = self._load_app
 
     def _build_kwargs(self):
         return {}
