@@ -1,15 +1,13 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2017 Alban 'spl0k' Féron
+# Copyright (C) 2017-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
 import time
 import unittest
 
-from pony.orm import db_session, commit
-
 from supysonic.db import Folder, Artist, Album, Track
 
 from .apitestbase import ApiTestBase
@@ -19,49 +17,49 @@ class SearchTestCase(ApiTestBase):
     def setUp(self):
         super().setUp()
 
-        with db_session:
-            root = Folder(root=True, name="Root folder", path="tests/assets")
+        root = Folder.create(root=True, name="Root folder", path="tests/assets")
+        Folder.create(root=True, name="Empty", path="/tmp")
 
-            for letter in "ABC":
-                folder = Folder(
-                    name=letter + "rtist",
-                    path="tests/assets/{}rtist".format(letter),
-                    parent=root,
+        for letter in "ABC":
+            folder = Folder.create(
+                name=letter + "rtist",
+                path=f"tests/assets/{letter}rtist",
+                root=False,
+                parent=root,
+            )
+            artist = Artist.create(name=letter + "rtist")
+
+            for lether in "AB":
+                afolder = Folder.create(
+                    name=letter + lether + "lbum",
+                    path="tests/assets/{0}rtist/{0}{1}lbum".format(letter, lether),
+                    root=False,
+                    parent=folder,
                 )
-                artist = Artist(name=letter + "rtist")
 
-                for lether in "AB":
-                    afolder = Folder(
-                        name=letter + lether + "lbum",
-                        path="tests/assets/{0}rtist/{0}{1}lbum".format(letter, lether),
-                        parent=folder,
+                album = Album.create(name=letter + lether + "lbum", artist=artist)
+
+                for num, song in enumerate(["One", "Two", "Three"]):
+                    Track.create(
+                        disc=1,
+                        number=num,
+                        title=song,
+                        duration=2,
+                        album=album,
+                        artist=artist,
+                        bitrate=320,
+                        path="tests/assets/{0}rtist/{0}{1}lbum/{2}".format(
+                            letter, lether, song
+                        ),
+                        last_modification=0,
+                        root_folder=root,
+                        folder=afolder,
                     )
 
-                    album = Album(name=letter + lether + "lbum", artist=artist)
-
-                    for num, song in enumerate(["One", "Two", "Three"]):
-                        Track(
-                            disc=1,
-                            number=num,
-                            title=song,
-                            duration=2,
-                            album=album,
-                            artist=artist,
-                            bitrate=320,
-                            path="tests/assets/{0}rtist/{0}{1}lbum/{2}".format(
-                                letter, lether, song
-                            ),
-                            last_modification=0,
-                            root_folder=root,
-                            folder=afolder,
-                        )
-
-            commit()
-
-            self.assertEqual(Folder.select().count(), 10)
-            self.assertEqual(Artist.select().count(), 3)
-            self.assertEqual(Album.select().count(), 6)
-            self.assertEqual(Track.select().count(), 18)
+        self.assertEqual(Folder.select().count(), 11)
+        self.assertEqual(Artist.select().count(), 3)
+        self.assertEqual(Album.select().count(), 6)
+        self.assertEqual(Track.select().count(), 18)
 
     def __track_as_pseudo_unique_str(self, elem):
         return elem.get("artist") + elem.get("album") + elem.get("title")
@@ -196,6 +194,10 @@ class SearchTestCase(ApiTestBase):
         self._make_request("search2", {"query": "a", "albumOffset": "sstring"}, error=0)
         self._make_request("search2", {"query": "a", "songCount": "string"}, error=0)
         self._make_request("search2", {"query": "a", "songOffset": "sstring"}, error=0)
+        self._make_request(
+            "search2", {"query": "a", "musicFolderId": "sstring"}, error=0
+        )
+        self._make_request("search2", {"query": "a", "musicFolderId": -2}, error=70)
 
         # no search
         self._make_request("search2", error=10)
@@ -288,6 +290,17 @@ class SearchTestCase(ApiTestBase):
                 self.assertNotIn(song, songs)
                 songs.append(song)
 
+        # root filtering
+        _, child = self._make_request(
+            "search2", {"query": "One", "musicFolderId": 1}, tag="searchResult2"
+        )
+        self.assertEqual(len(self._xpath(child, "./song")), 6)
+
+        _, child = self._make_request(
+            "search2", {"query": "One", "musicFolderId": 2}, tag="searchResult2"
+        )
+        self.assertEqual(len(self._xpath(child, "./song")), 0)
+
     # Almost identical as above. Test dataset (and tests) should probably be changed
     # to have folders that don't share names with artists or albums
     def test_search3(self):
@@ -300,6 +313,10 @@ class SearchTestCase(ApiTestBase):
         self._make_request("search3", {"query": "a", "albumOffset": "sstring"}, error=0)
         self._make_request("search3", {"query": "a", "songCount": "string"}, error=0)
         self._make_request("search3", {"query": "a", "songOffset": "sstring"}, error=0)
+        self._make_request(
+            "search3", {"query": "a", "musicFolderId": "sstring"}, error=0
+        )
+        self._make_request("search3", {"query": "a", "musicFolderId": -2}, error=70)
 
         # no search
         self._make_request("search3", error=10)
@@ -392,6 +409,17 @@ class SearchTestCase(ApiTestBase):
                 self.assertNotIn(song, songs)
                 songs.append(song)
 
+        # root filtering
+        _, child = self._make_request(
+            "search3", {"query": "One", "musicFolderId": 1}, tag="searchResult3"
+        )
+        self.assertEqual(len(self._xpath(child, "./song")), 6)
+
+        _, child = self._make_request(
+            "search3", {"query": "One", "musicFolderId": 2}, tag="searchResult3"
+        )
+        self.assertEqual(len(self._xpath(child, "./song")), 0)
+
 
 if __name__ == "__main__":
     unittest.main()
