@@ -1,7 +1,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2019-2020 Alban 'spl0k' Féron
+# Copyright (C) 2019-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -11,8 +11,6 @@ import sys
 import tempfile
 import unittest
 
-from pony.orm import db_session
-
 from supysonic.db import init_database, release_database
 from supysonic.managers.folder import FolderManager
 from supysonic.scanner import Scanner
@@ -23,8 +21,7 @@ class Issue148TestCase(unittest.TestCase):
     def setUp(self):
         self.__dir = tempfile.mkdtemp()
         init_database("sqlite:")
-        with db_session:
-            FolderManager.add("folder", self.__dir)
+        FolderManager.add("folder", self.__dir)
 
     def tearDown(self):
         release_database()
